@@ -21,12 +21,10 @@ class Window(tk.Tk):
     def __init__(self):
         super().__init__()
 
-        self.currentColl = config.COLLECTION
-        self.currentmode = True
-        self.__haData = False
+        self.__hasData = False
         self.title("App Configuration sample")
         self.label_text = tk.StringVar()
-        self.label_text.set('Get your Feature value after data is loaded')
+        self.label_text.set('Get your Configuration values after data is loaded')
 
         self.label = tk.Label(self, textvar=self.label_text)
         self.label.pack(fill=tk.BOTH, expand=1, padx=100, pady=30)
@@ -34,44 +32,20 @@ class Window(tk.Tk):
         hello_button = tk.Button(self, text="Get String Feature", command=lambda: self.fetch_feature('featurestring'))
         hello_button.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
 
-        numberic_button = tk.Button(self, text="Get Numeric Feature",
-                                    command=lambda: self.fetch_feature('featurenumeric'))
-        numberic_button.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
+        numeric_button = tk.Button(self, text="Get Numeric Feature",
+                                   command=lambda: self.fetch_feature('featurenumeric'))
+        numeric_button.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
 
         bool_button = tk.Button(self, text="Get Boolean Feature", command=lambda: self.fetch_feature('featurebool'))
         bool_button.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
 
-        change_button = tk.Button(self, text="Change CollectionId", command=lambda: self.change_collection())
-        change_button.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
-
-        change_Offline = tk.Button(self, text="Change CollectionId", command=lambda: self.change_collection())
-        change_Offline.pack(side=tk.LEFT, padx=(10, 20), pady=(0, 20))
-
         property_button = tk.Button(self, text="Property", command=lambda: self.fetch_property('numericproperty'))
         property_button.pack(side=tk.RIGHT, padx=(10, 20), pady=(0, 20))
 
-
-        self.initialize_app(collectionId=self.currentColl)
-
-    def change_mode(self):
-        app_config = AppConfiguration.get_instance()
-        app_config.enable_debug(True)
-        feature = app_config.get_feature("featurestring")
-        entity_attributes = {
-            'city': 'Bangalore',
-            'country': 'India'
-        }
-        val = feature.get_current_value()
-
-    def change_collection(self):
-        if self.currentColl == config.COLLECTION:
-            self.currentColl = config.COLLECTION1
-        else:
-            self.currentColl = config.COLLECTION
-        self.initialize_app(collectionId=self.currentColl, isOnLine=self.currentmode)
+        self.initialize_app()
 
     def fetch_property(self, property_id: str):
-        if self.__haData:
+        if self.__hasData:
             self.label.configure(background="red")
             app_config = AppConfiguration.get_instance()
             property_obj = app_config.get_property(property_id)
@@ -96,7 +70,7 @@ class Window(tk.Tk):
             self.label.configure(background="grey")
 
     def fetch_feature(self, feature_id: str):
-        if self.__haData:
+        if self.__hasData:
             self.label.configure(background="red")
             app_config = AppConfiguration.get_instance()
             feature = app_config.get_feature(feature_id)
@@ -129,19 +103,18 @@ class Window(tk.Tk):
             self.label.configure(background="red")
 
     def response(self):
-        self.__haData = True
+        self.__hasData = True
         self.label_text.set('Get your Feature value NOW')
 
-    def initialize_app(self, collectionId=str, isOnLine: bool = True):
-        app_config = AppConfiguration.get_instance()
-        app_config.override_server_host = config.URL
-        app_config.enable_debug(True)
-        app_config.init(region=AppConfiguration.REGION_US_SOUTH,
-                        guid=config.GUID,
-                        apikey=config.APIKEY)
-        app_config.set_context(collection_id=config.COLLECTION, environment_id=config.ENV, configuration_file=config.FILE, live_config_update_enabled=isOnLine)
-
-        app_config.register_configuration_update_listener(self.response)
+    def initialize_app(self):
+        appconfig_client = AppConfiguration.get_instance()
+        AppConfiguration.enable_debug(True)
+        appconfig_client.init(region=AppConfiguration.REGION_US_SOUTH,
+                              guid=config.GUID,
+                              apikey=config.APIKEY)
+        appconfig_client.set_context(collection_id=config.COLLECTION, environment_id=config.ENVIRONMENT)
+        appconfig_client.register_configuration_update_listener(self.response)
+        self.response()
 
 
 if __name__ == "__main__":
